==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/help/help_timeplans.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<title>TimePlans - Help</title>
<meta name="keywords" content="" />
<meta name="description" content="" />
<link href="../assets/css/styles.css" rel="stylesheet" type="text/css" media="screen" />
<link href="../assets/css/menu.css" media="screen" rel="stylesheet" type="text/css" />
<script src="../assets/js/jquery-min.js" type="text/javascript"></script>

</head>
<body>
<?php
$script=$_SERVER['SCRIPT_NAME']; 	$url = $_SERVER['SERVER_ADDR'];
$action = (isset ($_REQUEST['action'] )) ? $_REQUEST['action'] : "0";

?>
<div id="content">

<div class="logo">
<a href="#"><img src='../assets/images/logo.png'></img></a>
</div>

<div id="wrap">


<!-- header begins -->
<div class="menu-wrap">
<?php
	require('../assets/inc/header.php');
?>	
</div>
<!-- header ends -->



<div id="main">
<div class="wrapper">
<!-- content begins -->
<h3><span class="icon-clock2 greyicon"></span> TimePlans - Help</h3>

This page provides a simple way to add, edit and delete TimePlans on the system. The TimePlan form allows you to search, order or select TimePlans.<br/><br/>
<div style='text-align: center'><img src ='images/timeplans.jpg' /></div><br/><br/>


<span style='color:#00b300'><b> Add </b></span><br/>
To add a new TimePlan, click on the Add button, this will open the TimePlan form.<br/><br/>

<span style='color:#0000d9'><b> Edit </b></span><br/>
To edit an existing TimePlan, click on the required TimePlan and then on the Edit button, this will open the TimePlan form.<br/><br/>

<span style='color:#b30000'><b> Delete </b></span><br/>
To delete a TimePlan, click on the required TimePlan and then on the Delete button. A notification will be shown asking you to confirm the deletion of the TimePlan.<br/><br/>


<br/>The TimePlan form is used to add or edit a user. It has two tabs, TimePlan and Add Entries.<br/><br/>
If you are editing an existing TimePlan some of the fields will be pre populated.<br/><br/>

<h3>TimePlan Tab</h3>
The TimePlan tab allows you to configure TimePlan settings<br/><br/>
Hovering over the Time Bands tooltip <img src="../assets/images/tooltip.png" /> will show a summary of when the timeplans are active.<br><br>

<div class='colLeft'>
	<div style='text-align: center'><img src ='images/timeplan_form.jpg' /></div><br/><br/>
</div>

<div class='colRight'>
	<b>Name</b><br/>The name to be associated to this TimePlan<br/><br/>
	<b>Description</b><br/>A description to be associated to this TimePlan<br/><br/>
	<b>Mode</b><br/>Timed, Out Of Hours or In Hours.<br/><br/><b>Timed</b><br/>The entry will follow the configured time bands.<br/><b>Out of Hours</b><br/>The Time Plan considers itself to be outside of the hours specified by the Time Band(s)
	   regardless of the day or time.<br/><b>In Hours</b><br/>The Time Plan is operational, in other words it considers itself to be inside the hours specified by the Time Band(s) regardless of the day or time<br/><br/>
	<b>Alternate TimePlan</b><br/>The name of the Time Plan to be used on the days listed under Date Exception Entries.<br/><br/>
	<b>Time Bands</b><br/>Overview of currently configured Time Bands. To edit an entry click on the edit icon. To delete an entry click on the delete icon<br/><br/>
	<b>Date Exceptions</b><br/>Overview of currently configured Date Exceptions. To edit an entry click on the edit icon. To delete an entry click on the delete icon<br/><br/>
	<?php
	if ($adminCompany === '00000000-0000-0000-0000-000000000000') {
		echo "<b>Company</b><br/>Select the company this TimePlan belongs to. If this field is left empty, the TimePlan will not be added to a company.<br>(this entry is only shown to Administrators not assigned to a company)<br/><br/>";
	}
	?>
	Click the Close button to close the current TimeBand<br/><br/>
	Click the Save button to save the current TimeBand<br/><br/>
</div>

<h3>Add Entries Tab</h3>
The Add Entries tab allows you to edit or configure Time Band and Date Exception entries.<br/><br/>
<div class='colLeft'>
	<div style='text-align: center'><img src ='images/timeplan_entries.jpg' /></div><br/><br/>
</div>	
<div class='colRight'>
	<b>Edit Time Band</b><br/>
	From the TimeBand overview on the TimePlan tab click on the required time band. The time band will be displayed on the Add Entries tab. The Time Bands Start Day of Week and Time & End Day of Week and Time will be shown<br/><br/>
	
	<b>Add Time Band</b><br/>
	To add a new TimeBand complete the timeband fields entering a start day and time & the end day and time.<br/><br/>
	
	To change to the start or end day of week, select the required day from the drop down list<br/>To change the start or end time, click on the required time field and use the timepicker to enter the time<br/><br/>
	
	Click 'Save TimeBand' to update the TimePlan Entry<br/><br/>
	
	<b>Edit Date Exception</b><br/>
	From the Date Exceptions overview on the TimePlan tab click on the required date exception. The date exception will be displayed on the Add Entries tab. The date exceptions date will be shown in the date exception field<br/><br/>
	
	<b>Add Date Exception</b><br/>
	To add a new Date Exception click on the data exception field and select the required date<br/><br/>
	
	Click 'Save Date Exception' to update the TimePlan Entry<br/><br/>

</div>

<!--content ends -->
</div>
</div>	


<!--footer begins -->
<?php
	require('../assets/inc/footer.php');
?>
<!-- footer ends-->
</div>

</div>
</body>
</html>

==> SV1000-Linux.SV1.3.117.tar.gz: SpliceCom/WebManager/admin/help/help_timeplans.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<title>TimePlans - Help</title>
<meta name="keywords" content="" />
<meta name="description" content="" />
<link href="../assets/css/styles.css" rel="stylesheet" type="text/css" media="screen" />
<link href="../assets/css/menu.css" media="screen" rel="stylesheet" type="text/css" />
<script src="../assets/js/jquery-min.js" type="text/javascript"></script>

</head>
<body>
<?php
$script=$_SERVER['SCRIPT_NAME']; 	$url = $_SERVER['SERVER_ADDR'];
$action = (isset ($_REQUEST['action'] )) ? $_REQUEST['action'] : "0";

?>
<div id="content">

<div class="logo">
<a href="#"><img src='../assets/images/logo.png'></img></a>
</div>

<div id="wrap">


<!-- header begins -->
<div class="menu-wrap">
<?php
	require('../assets/inc/header.php');
?>	
</div>
<!-- header ends -->



<div id="main">
<div class="wrapper">
<!-- content begins -->
<h3><span class="icon-clock2 greyicon"></span> TimePlans - Help</h3>

This page provides a simple way to add, edit and delete TimePlans on the system. The TimePlan form allows you to search, order or select TimePlans.<br/><br/>
<div style='text-align: center'><img src ='images/timeplans.jpg' /></div><br/><br/>


<span style='color:#00b300'><b> Add </b></span><br/>
To add a new TimePlan, click on the Add button, this will open the TimePlan form.<br/><br/>

<span style='color:#0000d9'><b> Edit </b></span><br/>
To edit an existing TimePlan, click on the required TimePlan and then on the Edit button, this will open the TimePlan form.<br/><br/>

<span style='color:#b30000'><b> Delete </b></span><br/>
To delete a TimePlan, click on the required TimePlan and then on the Delete button. A notification will be shown asking you to confirm the deletion of the TimePlan.<br/><br/>


<br/>The TimePlan form is used to add or edit a user. It has two tabs, TimePlan and Add Entries.<br/><br/>
If you are editing an existing TimePlan some of the fields will be pre populated.<br/><br/>

<h3>TimePlan Tab</h3>
The TimePlan tab allows you to configure TimePlan settings<br/><br/>
Hovering over the Time Bands tooltip <img src="../assets/images/tooltip.png" /> will show a summary of when the timeplans are active.<br>
Please Note: A Time Bands End Time runs until the end of the minutes specified. eg: a Time Band with an End Time of 17:00 will run until 17:00.59<br>
The hover over will show the End Time and the start of an Inactive time period rounded to the nearest minute. eg: 17:01<br><br><br>

<div class='colLeft'>
	<div style='text-align: center'><img src ='images/timeplan_form.jpg' /></div><br/><br/>
</div>

<div class='colRight'>
	<b>Name</b><br/>The name to be associated to this TimePlan<br/><br/>
	<b>Description</b><br/>A description to be associated to this TimePlan<br/><br/>
	<b>Mode</b><br/>Timed, Out Of Hours or In Hours.<br/><br/><b>Timed</b><br/>The entry will follow the configured time bands.<br/><b>Out of Hours</b><br/>The Time Plan considers itself to be outside of the hours specified by the Time Band(s)
	   regardless of the day or time.<br/><b>In Hours</b><br/>The Time Plan is operational, in other words it considers itself to be inside the hours specified by the Time Band(s) regardless of the day or time<br/><br/>
	<b>Alternate TimePlan</b><br/>The name of the Time Plan to be used on the days listed under Date Exception Entries.<br/><br/>
	<b>Time Bands</b><br/>Overview of currently configured Time Bands. To edit an entry click on the edit icon. To delete an entry click on the delete icon<br/><br/>
	<b>Date Exceptions</b><br/>Overview of currently configured Date Exceptions. To edit an entry click on the edit icon. To delete an entry click on the delete icon<br/><br/>
	<?php
	if ($adminCompany === '00000000-0000-0000-0000-000000000000') {
		echo "<b>Company</b><br/>Select the company this TimePlan belongs to. If this field is left empty, the TimePlan will not be added to a company.<br>(this entry is only shown to Administrators not assigned to a company)<br/><br/>";
	}
	?>
	Click the Close button to close the current TimeBand<br/><br/>
	Click the Save button to save the current TimeBand<br/><br/>
</div>

<h3>Add Entries Tab</h3>
The Add Entries tab allows you to edit or configure Time Band and Date Exception entries.<br/><br/>
<div class='colLeft'>
	<div style='text-align: center'><img src ='images/timeplan_entries.jpg' /></div><br/><br/>
</div>	
<div class='colRight'>
	<b>Edit Time Band</b><br/>
	From the TimeBand overview on the TimePlan tab click on the required time band. The time band will be displayed on the Add Entries tab. The Time Bands Start Day of Week and Time & End Day of Week and Time will be shown<br/><br/>
	
	<b>Add Time Band</b><br/>
	To add a new TimeBand complete the timeband fields entering a start day and time & the end day and time.<br/><br/>
	
	To change to the start or end day of week, select the required day from the drop down list<br/>To change the start or end time, click on the required time field and use the timepicker to enter the time<br/><br/>
	
	Click 'Save TimeBand' to update the TimePlan Entry<br/><br/>
	
	<b>Edit Date Exception</b><br/>
	From the Date Exceptions overview on the TimePlan tab click on the required date exception. The date exception will be displayed on the Add Entries tab. The date exceptions date will be shown in the date exception field<br/><br/>
	
	<b>Add Date Exception</b><br/>
	To add a new Date Exception click on the data exception field and select the required date<br/><br/>
	
	Click 'Save Date Exception' to update the TimePlan Entry<br/><br/>

</div>

<!--content ends -->
</div>
</div>	


<!--footer begins -->
<?php
	require('../assets/inc/footer.php');
?>
<!-- footer ends-->
</div>

</div>
</body>
</html>
